@@ -1,17 +1,19 @@
 import os
-import rpy2.robjects as robjects
+import rpy2.robjects as ro
+from rpy2.robjects import pandas2ri, conversion
 
 
 def run_cellchat(count_matrix, pos_data, barcodes, meta, scale_data_dir, plot_dir, contact_range=100, spot_size=65, species='human'):
-    robjects.globalenv['count_matrix'] = count_matrix
-    robjects.globalenv['pos_data'] = pos_data
-    robjects.globalenv['barcodes'] = barcodes
-    robjects.globalenv['meta'] = meta
-    robjects.globalenv['scale_data_dir'] = scale_data_dir
-    robjects.globalenv['plot_dir'] = plot_dir
-    robjects.globalenv['contact_range'] = contact_range
-    robjects.globalenv['spot.size'] = spot_size
-    robjects.globalenv['species'] = species
+    with conversion.localconverter(ro.default_converter + pandas2ri.converter):
+        ro.globalenv['count_matrix'] = pandas2ri.py2rpy(count_matrix)
+        ro.globalenv['pos_data'] = pandas2ri.py2rpy(pos_data)
+        ro.globalenv['barcodes'] = pandas2ri.py2rpy(barcodes)
+        ro.globalenv['meta'] = pandas2ri.py2rpy(meta)
+        ro.globalenv['scale_data_dir'] = scale_data_dir
+        ro.globalenv['plot_dir'] = plot_dir
+        ro.globalenv['contact_range'] = contact_range
+        ro.globalenv['spot.size'] = spot_size
+        ro.globalenv['species'] = species
     
     os.makedirs(plot_dir, exist_ok=True)
 
@@ -92,6 +94,6 @@ def run_cellchat(count_matrix, pos_data, barcodes, meta, scale_data_dir, plot_di
     netVisual_aggregate(cellchat, signaling = pathways.show, layout = "circle", sources.use = c(5, 6), targets.use = c(1, 2, 4))
     dev.off()
     """
-    robjects.r('options(device = "png")')
-    robjects.r('options(width=100)')
-    robjects.r(r_code)
\ No newline at end of file
+    ro.r('options(device = "png")')
+    ro.r('options(width=100)')
+    ro.r(r_code)
\ No newline at end of file
